@@ -98,19 +98,19 @@ use vars qw{
   @site_rules_path
 };
 
-$VERSION = "3.000004";      # update after release (same format as perl $])
-$IS_DEVEL_BUILD = 0;        # change for release versions
+$VERSION = "3.000006";      # update after release (same format as perl $])
+# $IS_DEVEL_BUILD = 1;        # change for release versions
 
 @ISA = qw();
 
 # SUB_VERSION is now just <yyyy>-<mm>-<dd>
-$SUB_VERSION = (split(/\s+/,'$LastChangedDate: 2005-06-05 18:35:14 -0700 (Sun, 05 Jun 2005) $ updated by SVN'))[1];
+$SUB_VERSION = (split(/\s+/,'$LastChangedDate: 2005-12-07 16:42:29 -0800 (Wed, 07 Dec 2005) $ updated by SVN'))[1];
 
 # If you hacked up your SA, you should add a version_tag to you .cf files.
 # This variable should not be modified directly.
 @EXTRA_VERSION = qw();
 if (defined $IS_DEVEL_BUILD && $IS_DEVEL_BUILD) {
-  push(@EXTRA_VERSION, ( 'r' . qw{$LastChangedRevision: 180189 $ updated by SVN}[1] ));
+  push(@EXTRA_VERSION, ( 'r' . qw{$LastChangedRevision: 354923 $ updated by SVN}[1] ));
 }
 
 sub Version { $VERSION=~/^(\d+)\.(\d\d\d)(\d\d\d)$/; join('-', sprintf("%d.%d.%d",$1,$2,$3), @EXTRA_VERSION) }
@@ -861,7 +861,7 @@ sub remove_spamassassin_markup {
     my $cd = '';
     for ( my $i = 0 ; $i <= $#msg ; $i++ ) {
       # only look at mime part headers
-      next unless ( $msg[$i] =~ /^--$boundary$/ || $flag );
+      next unless ( $msg[$i] =~ /^--$boundary\r?$/ || $flag );
 
       if ( $msg[$i] =~ /^\s*$/ ) {    # end of mime header
 
